import { BaseAction } from "./base";
import { PCMutation } from "paperclip-source-writer";
import { VirtualNode, BasicPaperclipAction, EngineErrorEvent, LoadedData, VirtNodeSource } from "paperclip-utils";
import { Box, Directory, FSItemKind, Point, Size } from "../state";
export declare enum ActionType {
    RENDERER_CHANGED = "RENDERER_CHANGED",
    LOCATION_CHANGED = "LOCATION_CHANGED",
    RENDERER_MOUNTED = "RENDERER_MOUNTED",
    REDIRECT_REQUESTED = "REDIRECT_REQUESTED",
    ZOOM_IN_KEY_PRESSED = "ZOOM_IN_KEY_PRESSED",
    ZOOM_OUT_KEY_PRESSED = "ZOOM_OUT_KEY_PRESSED",
    BIRDSEYE_FILTER_CHANGED = "BIRDSEYE_FILTER_CHANGED",
    BIRDSEYE_TOP_FILTER_BLURRED = "BIRDSEYE_TOP_FILTER_BLURRED",
    RENDERER_UNMOUNTED = "RENDERER_UNMOUNTED",
    PC_FILE_OPENED = "PC_FILE_OPENED",
    GRID_BUTTON_CLICKED = "GRID_BUTTON_CLICKED",
    CLIENT_CONNECTED = "CLIENT_CONNECTED",
    ENGINE_ERRORED = "ENGINE_ERRORED",
    ERROR_BANNER_CLICKED = "ERROR_BANNER_CLICKED",
    CANVAS_MOUSE_LEAVE = "CANVAS_MOUSE_LEAVE",
    CANVAS_MOUSE_UP = "CANVAS_MOUSE_UP",
    CANVAS_DOUBLE_CLICK = "CANVAS_DOUBLE_CLICK",
    ZOOM_IN_BUTTON_CLICKED = "ZOOM_IN_BUTTON_CLICKED",
    POPOUT_BUTTON_CLICKED = "POPOUT_BUTTON_CLICKED",
    POPOUT_WINDOW_REQUESTED = "POPOUT_WINDOW_REQUESTED",
    PASTED = "PASTED",
    ZOOM_OUT_BUTTON_CLICKED = "ZOOM_OUT_BUTTON_CLICKED",
    ZOOM_INPUT_CHANGED = "ZOOM_INPUT_CHANGED",
    CANVAS_RESIZED = "CANVAS_RESIZED",
    CANVAS_MOUSE_MOVED = "CANVAS_MOUSE_MOVED",
    TITLE_DOUBLE_CLICKED = "TITLE_DOUBLE_CLICKED",
    DIR_LOADED = "DIR_LOADED",
    FS_ITEM_CLICKED = "FS_ITEM_CLICKED",
    VIRTUAL_NODES_SELECTED = "VIRTUAL_NODES_SELECTED",
    NODE_BREADCRUMB_CLICKED = "NODE_BREADCRUMB_CLICKED",
    NODE_BREADCRUMB_MOUSE_ENTERED = "NODE_BREADCRUMB_MOUSE_ENTERED",
    NODE_BREADCRUMB_MOUSE_LEFT = "NODE_BREADCRUMB_MOUSE_LEFT",
    CANVAS_PAN_START = "CANVAS_PAN_START",
    CANVAS_PAN_END = "CANVAS_PAN_END",
    CANVAS_PANNED = "CANVAS_PANNED",
    RECTS_CAPTURED = "RECTS_CAPTURED",
    GLOBAL_ESCAPE_KEY_PRESSED = "GLOBAL_ESCAPE_KEY_PRESSED",
    GLOBAL_META_KEY_DOWN = "GLOBAL_META_KEY_DOWN",
    GLOBAL_OPTION_KEY_DOWN = "GLOBAL_OPTION_KEY_DOWN",
    GLOBAL_Z_KEY_DOWN = "GLOBAL_Z_KEY_DOWN",
    GLOBAL_Y_KEY_DOWN = "GLOBAL_Y_KEY_DOWN",
    GLOBAL_H_KEY_DOWN = "GLOBAL_H_KEY_DOWN",
    GRID_HOTKEY_PRESSED = "GRID_HOTKEY_PRESSED",
    GET_ALL_SCREENS_REQUESTED = "GET_ALL_SCREENS_REQUESTED",
    GLOBAL_SAVE_KEY_DOWN = "GLOBAL_SAVE_KEY_DOWN",
    GLOBAL_BACKSPACE_KEY_PRESSED = "GLOBAL_BACKSPACE_KEY_PRESSED",
    GLOBAL_BACKSPACE_KEY_SENT = "GLOBAL_BACKSPACE_KEY_SENT",
    GLOBAL_META_KEY_UP = "GLOBAL_META_KEY_UP",
    GLOBAL_OPTION_KEY_UP = "GLOBAL_OPTION_KEY_UP",
    ENGINE_DELEGATE_CHANGED = "ENGINE_DELEGATE_CHANGED",
    ENGINE_DELEGATE_EVENTS_HANDLED = "ENGINE_DELEGATE_EVENTS_HANDLED",
    FRAME_TITLE_CLICKED = "FRAME_TITLE_CLICKED",
    FILE_OPENED = "FILE_OPENED",
    RESIZER_PATH_MOUSE_MOVED = "RESIZER_PATH_MOUSE_MOVED",
    RESIZER_MOVED = "RESIZER_MOVED",
    RESIZER_STOPPED_MOVING = "RESIZER_STOPPED_MOVING",
    RESIZER_PATH_MOUSE_STOPPED_MOVING = "RESIZER_PATH_MOUSE_STOPPED_MOVING",
    META_CLICKED = "META_CLICKED",
    PC_VIRT_OBJECT_EDITED = "PC_VIRT_OBJECT_EDITED",
    SERVER_OPTIONS_LOADED = "SERVER_OPTIONS_LOADED",
    ACTION_HANDLED = "ACTION_HANDLED",
    FRAME_TITLE_CHANGED = "FRAME_TITLE_CHANGED",
    EXPAND_FRAME_BUTTON_CLICKED = "EXPAND_FRAME_BUTTON_CLICKED",
    COLLAPSE_FRAME_BUTTON_CLICKED = "COLLAPSE_FRAME_BUTTON_CLICKED",
    VISUAL_EDITOR_INSTANCE_CHANGED = "VISUAL_EDITOR_INSTANCE_CHANGED",
    VIRTUAL_STYLE_DECLARATION_VALUE_CHANGED = "VIRTUAL_STYLE_DECLARATION_VALUE_CHANGED",
    STYLE_RULE_FILE_NAME_CLICKED = "STYLE_RULE_FILE_NAME_CLICKED",
    LAYER_LEAF_CLICKED = "LAYER_LEAF_CLICKED",
    LAYER_EXPAND_TOGGLE_CLICKED = "LAYER_EXPAND_TOGGLE_CLICKED",
    WINDOW_FOCUSED = "WINDOW_FOCUSED",
    WINDOW_BLURRED = "WINDOW_BLURRED"
}
export declare type WrappedEvent<T, TType extends ActionType, TPayload = undefined> = {
    sourceEvent: T;
} & BaseAction<TType, TPayload>;
export declare type ResizerMoved = WrappedEvent<MouseEvent, ActionType.RESIZER_MOVED, {
    originalBounds: Box;
    newBounds: Box;
    anchor: Point;
}>;
export declare type RendererMounted = BaseAction<ActionType.RENDERER_MOUNTED, {
    id: string;
}>;
export declare type RendererUnmounted = BaseAction<ActionType.RENDERER_UNMOUNTED, {
    id: string;
}>;
export declare type GridButtonClicked = BaseAction<ActionType.GRID_BUTTON_CLICKED>;
export declare type ResizerStoppedMoving = WrappedEvent<MouseEvent, ActionType.RESIZER_STOPPED_MOVING, {
    originalBounds: Box;
    newBounds: Box;
    anchor: Point;
}>;
export declare type ServerOptionsLoaded = BaseAction<ActionType.SERVER_OPTIONS_LOADED, {
    localResourceRoots: string[];
}>;
export declare type NodeBreadcrumbClicked = BaseAction<ActionType.NODE_BREADCRUMB_CLICKED, {
    nodePath: string;
    metaKey: boolean;
}>;
export declare type NodeBreadcrumbMouseEntered = BaseAction<ActionType.NODE_BREADCRUMB_MOUSE_ENTERED, {
    nodePath: string;
}>;
export declare type NodeBreadcrumbMouseLeft = BaseAction<ActionType.NODE_BREADCRUMB_MOUSE_LEFT, {
    nodePath: string;
}>;
export declare type GridHotkeyPressed = WrappedEvent<MouseEvent, ActionType.GRID_HOTKEY_PRESSED>;
export declare type GetAllScreensRequested = WrappedEvent<MouseEvent, ActionType.GET_ALL_SCREENS_REQUESTED>;
export declare type VirtualNodesSelected = BaseAction<ActionType.VIRTUAL_NODES_SELECTED, {
    sources: Array<VirtNodeSource>;
    screenWidth: number;
}>;
export declare type MetaClicked = BaseAction<ActionType.META_CLICKED, {
    nodePath: number[];
    nodeUri: string;
}>;
export declare type BirdseyeFilterChanged = BaseAction<ActionType.BIRDSEYE_FILTER_CHANGED, {
    value: string;
}>;
export declare type VirtualStyleDeclarationValueChanged = BaseAction<ActionType.VIRTUAL_STYLE_DECLARATION_VALUE_CHANGED, {
    declarationId: string;
    name: string;
    value: string;
}>;
export declare type StyleRuleFileNameClicked = BaseAction<ActionType.STYLE_RULE_FILE_NAME_CLICKED, {
    styleRuleSourceId: string;
}>;
export declare type TitleDoubleClicked = BaseAction<ActionType.TITLE_DOUBLE_CLICKED, {
    uri: string;
}>;
export declare type BirdseyeTopFilterBlurred = BaseAction<ActionType.BIRDSEYE_TOP_FILTER_BLURRED>;
export declare type PCFileLoaded = BaseAction<ActionType.PC_FILE_OPENED, {
    uri: string;
    data: LoadedData;
    document: string;
}>;
export declare type ClientConnected = BaseAction<ActionType.CLIENT_CONNECTED>;
export declare type LocationChanged = BaseAction<ActionType.LOCATION_CHANGED, {
    protocol: string;
    host: string;
    pathname: string;
    query: any;
}>;
export declare type LayerLeafClicked = BaseAction<ActionType.LAYER_LEAF_CLICKED, {
    nodePath: string;
    metaKey: boolean;
}>;
export declare type LayerExpandToggleClicked = BaseAction<ActionType.LAYER_EXPAND_TOGGLE_CLICKED, {
    nodePath: string;
}>;
export declare type RedirectRequested = BaseAction<ActionType.REDIRECT_REQUESTED, {
    pathname?: string;
    query?: any;
}>;
export declare type ExpandFrameButtonClicked = BaseAction<ActionType.EXPAND_FRAME_BUTTON_CLICKED, {
    frameIndex: number;
}>;
export declare type CollapseFrameButtonClicked = BaseAction<ActionType.COLLAPSE_FRAME_BUTTON_CLICKED>;
export declare type ResizerPathMoved = WrappedEvent<MouseEvent, ActionType.RESIZER_PATH_MOUSE_MOVED, {
    originalBounds: Box;
    newBounds: Box;
}>;
export declare type PopoutButtonClicked = BaseAction<ActionType.POPOUT_BUTTON_CLICKED>;
export declare type PopoutWindowRequested = BaseAction<ActionType.POPOUT_WINDOW_REQUESTED, {
    uri: string;
}>;
export declare type ResizerPathStoppedMoving = WrappedEvent<MouseEvent, ActionType.RESIZER_PATH_MOUSE_STOPPED_MOVING, {
    originalBounds: Box;
    newBounds: Box;
}>;
export declare type PCVirtObjectEdited = BaseAction<ActionType.PC_VIRT_OBJECT_EDITED, {
    mutations: PCMutation[];
}>;
export declare type FrameTitleChanged = BaseAction<ActionType.FRAME_TITLE_CHANGED, {
    frameIndex: number;
    value: string;
}>;
export declare type Pasted = BaseAction<ActionType.PASTED, {
    clipboardData: Array<{
        type: string;
        content: string;
    }>;
}>;
export declare type FrameTitleClicked = BaseAction<ActionType.FRAME_TITLE_CLICKED, {
    frameIndex: number;
    shiftKey: boolean;
}>;
export declare type EngineDelegateEventsHandled = BaseAction<ActionType.ENGINE_DELEGATE_EVENTS_HANDLED, {
    count: number;
    id: string;
}>;
export declare type FileOpened = BaseAction<ActionType.FILE_OPENED, {
    uri: string;
}>;
export declare type RendererChanged = BaseAction<ActionType.RENDERER_CHANGED, {
    virtualRoot: VirtualNode;
}>;
export declare type CanvasMouseUp = BaseAction<ActionType.CANVAS_MOUSE_UP, {
    metaKey: boolean;
    ctrlKey: boolean;
    shiftKey: boolean;
    timestamp: number;
}>;
export declare type CanvasDoubleClick = BaseAction<ActionType.CANVAS_DOUBLE_CLICK, Point>;
export declare type CanvasMouseLeave = BaseAction<ActionType.CANVAS_MOUSE_LEAVE, {
    mousePosition: Point;
}>;
export declare type CanvasPanned = BaseAction<ActionType.CANVAS_PANNED, {
    delta: Point;
    metaKey: boolean;
    ctrlKey: boolean;
    mousePosition: Point;
    size: Size;
}>;
export declare type CanvasPanStart = BaseAction<ActionType.CANVAS_PAN_START>;
export declare type CanvasPanEnd = BaseAction<ActionType.CANVAS_PAN_END>;
export declare type CanvasResized = BaseAction<ActionType.CANVAS_RESIZED, Size>;
export declare type CanvasMouseMoved = BaseAction<ActionType.CANVAS_MOUSE_MOVED, Point>;
export declare type ActionHandled = BaseAction<ActionType.ACTION_HANDLED>;
export declare type EngineErrored = BaseAction<ActionType.ENGINE_ERRORED, EngineErrorEvent>;
export declare type ErrorBannerClicked = BaseAction<ActionType.ERROR_BANNER_CLICKED, EngineErrorEvent>;
export declare type ZoomInButtonClicked = BaseAction<ActionType.ZOOM_IN_BUTTON_CLICKED>;
export declare type ZoomOutButtonClicked = BaseAction<ActionType.ZOOM_OUT_BUTTON_CLICKED>;
export declare type ZoomInputChanged = BaseAction<ActionType.ZOOM_INPUT_CHANGED, {
    value: number;
}>;
export declare type DirLoaded = BaseAction<ActionType.DIR_LOADED, {
    isRoot: boolean;
    item: Directory;
}>;
export declare type FSItemClicked = BaseAction<ActionType.FS_ITEM_CLICKED, {
    absolutePath: string;
    url: string;
    kind: FSItemKind;
}>;
export declare type RectsCaptured = BaseAction<ActionType.RECTS_CAPTURED, Record<string, Box>>;
export declare type KeyComboPressed<TType extends ActionType> = BaseAction<TType, null>;
export declare const pcVirtObjectEdited: (payload: {
    mutations: PCMutation[];
}) => {
    type: ActionType.PC_VIRT_OBJECT_EDITED;
    payload: {
        mutations: PCMutation[];
    };
    public: boolean;
};
export declare const gridButtonClicked: (payload: undefined) => {
    type: ActionType.GRID_BUTTON_CLICKED;
    payload: undefined;
    public: boolean;
};
export declare const frameTitleClicked: (payload: {
    frameIndex: number;
    shiftKey: boolean;
}) => {
    type: ActionType.FRAME_TITLE_CLICKED;
    payload: {
        frameIndex: number;
        shiftKey: boolean;
    };
    public: boolean;
};
export declare const frameTitleChanged: (payload: {
    frameIndex: number;
    value: string;
}) => {
    type: ActionType.FRAME_TITLE_CHANGED;
    payload: {
        frameIndex: number;
        value: string;
    };
    public: boolean;
};
export declare const titleDoubleClicked: (payload: {
    uri: string;
}) => {
    type: ActionType.TITLE_DOUBLE_CLICKED;
    payload: {
        uri: string;
    };
    public: boolean;
};
export declare const rendererMounted: (payload: {
    id: string;
}) => {
    type: ActionType.RENDERER_MOUNTED;
    payload: {
        id: string;
    };
    public: boolean;
};
export declare const rendererUnounted: (payload: {
    id: string;
}) => {
    type: ActionType.RENDERER_UNMOUNTED;
    payload: {
        id: string;
    };
    public: boolean;
};
export declare const birdseyeFilterChanged: (payload: {
    value: string;
}) => {
    type: ActionType.BIRDSEYE_FILTER_CHANGED;
    payload: {
        value: string;
    };
    public: boolean;
};
export declare const redirectRequest: (payload: {
    pathname?: string;
    query?: any;
}) => {
    type: ActionType.REDIRECT_REQUESTED;
    payload: {
        pathname?: string;
        query?: any;
    };
    public: boolean;
};
export declare const nodeBreadcrumbClicked: (payload: {
    nodePath: string;
    metaKey: boolean;
}) => {
    type: ActionType.NODE_BREADCRUMB_CLICKED;
    payload: {
        nodePath: string;
        metaKey: boolean;
    };
    public: boolean;
};
export declare const nodeBreadcrumbMouseEntered: (payload: {
    nodePath: string;
}) => {
    type: ActionType.NODE_BREADCRUMB_MOUSE_ENTERED;
    payload: {
        nodePath: string;
    };
    public: boolean;
};
export declare const nodeBreadcrumbMouseLeft: (payload: {
    nodePath: string;
}) => {
    type: ActionType.NODE_BREADCRUMB_MOUSE_LEFT;
    payload: {
        nodePath: string;
    };
    public: boolean;
};
export declare const engineDelegateEventsHandled: (payload: {
    count: number;
    id: string;
}) => {
    type: ActionType.ENGINE_DELEGATE_EVENTS_HANDLED;
    payload: {
        count: number;
        id: string;
    };
    public: boolean;
};
export declare const fileOpened: (payload: {
    uri: string;
}) => {
    type: ActionType.FILE_OPENED;
    payload: {
        uri: string;
    };
    public: boolean;
};
export declare const errorBannerClicked: (payload: EngineErrorEvent) => {
    type: ActionType.ERROR_BANNER_CLICKED;
    payload: EngineErrorEvent;
    public: boolean;
};
export declare const pcFileLoaded: (payload: {
    uri: string;
    data: LoadedData;
    document: string;
}) => {
    type: ActionType.PC_FILE_OPENED;
    payload: {
        uri: string;
        data: LoadedData;
        document: string;
    };
    public: boolean;
};
export declare const expandFrameButtonClicked: (payload: {
    frameIndex: number;
}) => {
    type: ActionType.EXPAND_FRAME_BUTTON_CLICKED;
    payload: {
        frameIndex: number;
    };
    public: boolean;
};
export declare const collapseFrameButtonClicked: (payload: undefined) => {
    type: ActionType.COLLAPSE_FRAME_BUTTON_CLICKED;
    payload: undefined;
    public: boolean;
};
export declare const resizerPathMoved: (payload: {
    originalBounds: Box;
    newBounds: Box;
}) => {
    type: ActionType.RESIZER_PATH_MOUSE_MOVED;
    payload: {
        originalBounds: Box;
        newBounds: Box;
    };
    public: boolean;
};
export declare const locationChanged: (payload: {
    protocol: string;
    host: string;
    pathname: string;
    query: any;
}) => {
    type: ActionType.LOCATION_CHANGED;
    payload: {
        protocol: string;
        host: string;
        pathname: string;
        query: any;
    };
    public: boolean;
};
export declare const virtualStyleDeclarationValueChanged: (payload: {
    declarationId: string;
    name: string;
    value: string;
}) => {
    type: ActionType.VIRTUAL_STYLE_DECLARATION_VALUE_CHANGED;
    payload: {
        declarationId: string;
        name: string;
        value: string;
    };
    public: boolean;
};
export declare const styleRuleFileNameClicked: (payload: {
    styleRuleSourceId: string;
}) => {
    type: ActionType.STYLE_RULE_FILE_NAME_CLICKED;
    payload: {
        styleRuleSourceId: string;
    };
    public: boolean;
};
export declare const metaClicked: (payload: {
    nodePath: number[];
    nodeUri: string;
}) => {
    type: ActionType.META_CLICKED;
    payload: {
        nodePath: number[];
        nodeUri: string;
    };
    public: boolean;
};
export declare const resizerPathStoppedMoving: (payload: {
    originalBounds: Box;
    newBounds: Box;
}) => {
    type: ActionType.RESIZER_PATH_MOUSE_STOPPED_MOVING;
    payload: {
        originalBounds: Box;
        newBounds: Box;
    };
    public: boolean;
};
export declare const layerLeafClicked: (payload: {
    nodePath: string;
    metaKey: boolean;
}) => {
    type: ActionType.LAYER_LEAF_CLICKED;
    payload: {
        nodePath: string;
        metaKey: boolean;
    };
    public: boolean;
};
export declare const layerExpandToggleClicked: (payload: {
    nodePath: string;
}) => {
    type: ActionType.LAYER_EXPAND_TOGGLE_CLICKED;
    payload: {
        nodePath: string;
    };
    public: boolean;
};
export declare const actionHandled: (payload: undefined) => {
    type: ActionType.ACTION_HANDLED;
    payload: undefined;
    public: boolean;
};
export declare const birdseyeTopFilterBlurred: (payload: undefined) => {
    type: ActionType.BIRDSEYE_TOP_FILTER_BLURRED;
    payload: undefined;
    public: boolean;
};
export declare const resizerMoved: (payload: {
    originalBounds: Box;
    newBounds: Box;
    anchor: Point;
}) => {
    type: ActionType.RESIZER_MOVED;
    payload: {
        originalBounds: Box;
        newBounds: Box;
        anchor: Point;
    };
    public: boolean;
};
export declare const resizerStoppedMoving: (payload: {
    originalBounds: Box;
    newBounds: Box;
    anchor: Point;
}) => {
    type: ActionType.RESIZER_STOPPED_MOVING;
    payload: {
        originalBounds: Box;
        newBounds: Box;
        anchor: Point;
    };
    public: boolean;
};
export declare const rectsCaptured: (payload: Record<string, Box>) => {
    type: ActionType.RECTS_CAPTURED;
    payload: Record<string, Box>;
    public: boolean;
};
export declare const canvasMouseUp: (payload: {
    metaKey: boolean;
    ctrlKey: boolean;
    shiftKey: boolean;
    timestamp: number;
}) => {
    type: ActionType.CANVAS_MOUSE_UP;
    payload: {
        metaKey: boolean;
        ctrlKey: boolean;
        shiftKey: boolean;
        timestamp: number;
    };
    public: boolean;
};
export declare const canvasDoubleClick: (payload: Point) => {
    type: ActionType.CANVAS_DOUBLE_CLICK;
    payload: Point;
    public: boolean;
};
export declare const canvasMouseLeave: (payload: {
    mousePosition: Point;
}) => {
    type: ActionType.CANVAS_MOUSE_LEAVE;
    payload: {
        mousePosition: Point;
    };
    public: boolean;
};
export declare const canvasPanned: (payload: {
    delta: Point;
    metaKey: boolean;
    ctrlKey: boolean;
    mousePosition: Point;
    size: Size;
}) => {
    type: ActionType.CANVAS_PANNED;
    payload: {
        delta: Point;
        metaKey: boolean;
        ctrlKey: boolean;
        mousePosition: Point;
        size: Size;
    };
    public: boolean;
};
export declare const canvasPanStart: (payload: undefined) => {
    type: ActionType.CANVAS_PAN_START;
    payload: undefined;
    public: boolean;
};
export declare const canvasPanEnd: (payload: undefined) => {
    type: ActionType.CANVAS_PAN_END;
    payload: undefined;
    public: boolean;
};
export declare const canvasResized: (payload: Size) => {
    type: ActionType.CANVAS_RESIZED;
    payload: Size;
    public: boolean;
};
export declare const canvasMouseMoved: (payload: Point) => {
    type: ActionType.CANVAS_MOUSE_MOVED;
    payload: Point;
    public: boolean;
};
export declare const rendererChanged: (payload: {
    virtualRoot: VirtualNode;
}) => {
    type: ActionType.RENDERER_CHANGED;
    payload: {
        virtualRoot: VirtualNode;
    };
    public: boolean;
};
export declare const engineErrored: (payload: EngineErrorEvent) => {
    type: ActionType.ENGINE_ERRORED;
    payload: EngineErrorEvent;
    public: boolean;
};
export declare const zoomInButtonClicked: (payload: undefined) => {
    type: ActionType.ZOOM_IN_BUTTON_CLICKED;
    payload: undefined;
    public: boolean;
};
export declare const zoomOutButtonClicked: (payload: undefined) => {
    type: ActionType.ZOOM_OUT_BUTTON_CLICKED;
    payload: undefined;
    public: boolean;
};
export declare const zoomInputChanged: (payload: {
    value: number;
}) => {
    type: ActionType.ZOOM_INPUT_CHANGED;
    payload: {
        value: number;
    };
    public: boolean;
};
export declare const popoutWindowRequested: (payload: {
    uri: string;
}) => {
    type: ActionType.POPOUT_WINDOW_REQUESTED;
    payload: {
        uri: string;
    };
    public: boolean;
};
export declare const globalEscapeKeyPressed: (payload: null) => {
    type: ActionType.GLOBAL_ESCAPE_KEY_PRESSED;
    payload: null;
    public: boolean;
};
export declare const globalBackspaceKeyPressed: (payload: null) => {
    type: ActionType.GLOBAL_BACKSPACE_KEY_PRESSED;
    payload: null;
    public: boolean;
};
export declare const globalBackspaceKeySent: (payload: null) => {
    type: ActionType.GLOBAL_BACKSPACE_KEY_SENT;
    payload: null;
    public: boolean;
};
export declare const globalMetaKeyDown: (payload: null) => {
    type: ActionType.GLOBAL_META_KEY_DOWN;
    payload: null;
    public: boolean;
};
export declare const globalOptionKeyDown: (payload: null) => {
    type: ActionType.GLOBAL_OPTION_KEY_DOWN;
    payload: null;
    public: boolean;
};
export declare const globalZKeyDown: (payload: null) => {
    type: ActionType;
    payload: null;
    public: boolean;
};
export declare const popoutButtonClicked: (payload: undefined) => {
    type: ActionType.POPOUT_BUTTON_CLICKED;
    payload: undefined;
    public: boolean;
};
export declare const clientConnected: (payload: undefined) => {
    type: ActionType.CLIENT_CONNECTED;
    payload: undefined;
    public: boolean;
};
export declare const globalYKeyDown: (payload: null) => {
    type: ActionType;
    payload: null;
    public: boolean;
};
export declare const globalHKeyDown: (payload: null) => {
    type: ActionType;
    payload: null;
    public: boolean;
};
export declare const globalSaveKeyPress: (payload: null) => {
    type: ActionType;
    payload: null;
    public: boolean;
};
export declare const windowFocused: (payload: undefined) => {
    type: ActionType.WINDOW_FOCUSED;
    payload: undefined;
    public: boolean;
};
export declare const windowBlurred: (payload: undefined) => {
    type: ActionType.WINDOW_BLURRED;
    payload: undefined;
    public: boolean;
};
export declare const globalMetaKeyUp: (payload: null) => {
    type: ActionType.GLOBAL_META_KEY_UP;
    payload: null;
    public: boolean;
};
export declare const globalOptionKeyUp: (payload: null) => {
    type: ActionType.GLOBAL_OPTION_KEY_UP;
    payload: null;
    public: boolean;
};
export declare const dirLoaded: (payload: {
    isRoot: boolean;
    item: Directory;
}) => {
    type: ActionType.DIR_LOADED;
    payload: {
        isRoot: boolean;
        item: Directory;
    };
    public: boolean;
};
export declare const fsItemClicked: (payload: {
    absolutePath: string;
    url: string;
    kind: FSItemKind;
}) => {
    type: ActionType.FS_ITEM_CLICKED;
    payload: {
        absolutePath: string;
        url: string;
        kind: FSItemKind;
    };
    public: boolean;
};
export declare const pasted: (payload: {
    clipboardData: Array<{
        type: string;
        content: string;
    }>;
}) => {
    type: ActionType.PASTED;
    payload: {
        clipboardData: Array<{
            type: string;
            content: string;
        }>;
    };
    public: boolean;
};
export declare const gridHotkeyPressed: (payload: undefined) => {
    type: ActionType.GRID_HOTKEY_PRESSED;
    payload: undefined;
    public: boolean;
};
export declare const getAllScreensRequested: (payload: undefined) => {
    type: ActionType.GET_ALL_SCREENS_REQUESTED;
    payload: undefined;
    public: boolean;
};
export declare const zoomInKeyPressed: (payload: null) => {
    type: ActionType.ZOOM_IN_KEY_PRESSED;
    payload: null;
    public: boolean;
};
export declare const zoomOutKeyPressed: (payload: null) => {
    type: ActionType.ZOOM_OUT_KEY_PRESSED;
    payload: null;
    public: boolean;
};
export declare const virtualNodesSelected: (payload: {
    sources: Array<VirtNodeSource>;
    screenWidth: number;
}) => {
    type: ActionType.VIRTUAL_NODES_SELECTED;
    payload: {
        sources: Array<VirtNodeSource>;
        screenWidth: number;
    };
    public: boolean;
};
export declare const serverOptionsLoaded: (payload: {
    localResourceRoots: string[];
}) => {
    type: ActionType.SERVER_OPTIONS_LOADED;
    payload: {
        localResourceRoots: string[];
    };
    public: boolean;
};
export declare type InstanceAction = RectsCaptured | CanvasMouseUp | ResizerPathMoved | VirtualStyleDeclarationValueChanged | VirtualNodesSelected | NodeBreadcrumbClicked | ResizerPathStoppedMoving | NodeBreadcrumbMouseEntered | NodeBreadcrumbMouseLeft | Pasted | RendererMounted | RedirectRequested | RendererUnmounted | ServerOptionsLoaded | BirdseyeFilterChanged | FrameTitleChanged | MetaClicked | ResizerStoppedMoving | BirdseyeTopFilterBlurred | ResizerMoved | GridHotkeyPressed | RendererChanged | CanvasPanned | CanvasPanStart | PCVirtObjectEdited | CanvasMouseLeave | PCFileLoaded | GridButtonClicked | GetAllScreensRequested | CanvasPanEnd | PopoutWindowRequested | CanvasResized | CanvasMouseMoved | ErrorBannerClicked | FileOpened | MetaClicked | LocationChanged | TitleDoubleClicked | PopoutButtonClicked | CollapseFrameButtonClicked | ExpandFrameButtonClicked | BasicPaperclipAction | ZoomInButtonClicked | ActionHandled | StyleRuleFileNameClicked | LayerExpandToggleClicked | LayerLeafClicked | CanvasDoubleClick | ZoomInputChanged | ClientConnected | FrameTitleClicked | EngineDelegateEventsHandled | KeyComboPressed<ActionType.GLOBAL_OPTION_KEY_DOWN> | KeyComboPressed<ActionType.GLOBAL_OPTION_KEY_UP> | KeyComboPressed<ActionType.GLOBAL_META_KEY_DOWN> | KeyComboPressed<ActionType.ZOOM_IN_KEY_PRESSED> | KeyComboPressed<ActionType.ZOOM_OUT_KEY_PRESSED> | KeyComboPressed<ActionType.GLOBAL_META_KEY_UP> | KeyComboPressed<ActionType.GLOBAL_SAVE_KEY_DOWN> | KeyComboPressed<ActionType.GLOBAL_ESCAPE_KEY_PRESSED> | KeyComboPressed<ActionType.GLOBAL_BACKSPACE_KEY_PRESSED> | KeyComboPressed<ActionType.GLOBAL_BACKSPACE_KEY_SENT> | KeyComboPressed<ActionType.GLOBAL_Y_KEY_DOWN> | KeyComboPressed<ActionType.GLOBAL_Z_KEY_DOWN> | KeyComboPressed<ActionType.GLOBAL_H_KEY_DOWN> | ReturnType<typeof windowFocused> | ReturnType<typeof windowBlurred> | EngineErrored | ZoomOutButtonClicked | DirLoaded | FSItemClicked;
